==> kubernetes-model-certificates-4.13.3-sources.jar: io/fabric8/kubernetes/api/model/certificates/CertificateSigningRequestSpecFluent.java <==
package io.fabric8.kubernetes.api.model.certificates;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.util.LinkedHashMap;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface CertificateSigningRequestSpecFluent<A extends CertificateSigningRequestSpecFluent<A>> extends Fluent<A> {


    public A addToExtra(String key,ArrayList<String> value);
    public A addToExtra(Map<String,ArrayList<String>> map);
    public A removeFromExtra(String key);
    public A removeFromExtra(Map<String,ArrayList<String>> map);
    public Map<String,ArrayList<String>> getExtra();
    public A withExtra(Map<String,ArrayList<String>> extra);
    public Boolean hasExtra();
    public A addToGroups(int index,String item);
    public A setToGroups(int index,String item);
    public A addToGroups(String... items);
    public A addAllToGroups(Collection<String> items);
    public A removeFromGroups(String... items);
    public A removeAllFromGroups(Collection<String> items);
    public List<String> getGroups();
    public String getGroup(int index);
    public String getFirstGroup();
    public String getLastGroup();
    public String getMatchingGroup(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingGroup(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withGroups(List<String> groups);
    public A withGroups(String... groups);
    public Boolean hasGroups();
    public A addNewGroup(String arg1);
    public A addNewGroup(StringBuilder arg1);
    public A addNewGroup(StringBuffer arg1);
    public String getRequest();
    public A withRequest(String request);
    public Boolean hasRequest();
    public A withNewRequest(String arg1);
    public A withNewRequest(StringBuilder arg1);
    public A withNewRequest(StringBuffer arg1);
    public String getSignerName();
    public A withSignerName(String signerName);
    public Boolean hasSignerName();
    public A withNewSignerName(String arg1);
    public A withNewSignerName(StringBuilder arg1);
    public A withNewSignerName(StringBuffer arg1);
    public String getUid();
    public A withUid(String uid);
    public Boolean hasUid();
    public A withNewUid(String arg1);
    public A withNewUid(StringBuilder arg1);
    public A withNewUid(StringBuffer arg1);
    public A addToUsages(int index,String item);
    public A setToUsages(int index,String item);
    public A addToUsages(String... items);
    public A addAllToUsages(Collection<String> items);
    public A removeFromUsages(String... items);
    public A removeAllFromUsages(Collection<String> items);
    public List<String> getUsages();
    public String getUsage(int index);
    public String getFirstUsage();
    public String getLastUsage();
    public String getMatchingUsage(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingUsage(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withUsages(List<String> usages);
    public A withUsages(String... usages);
    public Boolean hasUsages();
    public A addNewUsage(String arg1);
    public A addNewUsage(StringBuilder arg1);
    public A addNewUsage(StringBuffer arg1);
    public String getUsername();
    public A withUsername(String username);
    public Boolean hasUsername();
    public A withNewUsername(String arg1);
    public A withNewUsername(StringBuilder arg1);
    public A withNewUsername(StringBuffer arg1);
}

==> kubernetes-model-certificates-5.0.3-sources.jar: io/fabric8/kubernetes/api/model/certificates/CertificateSigningRequestSpecFluent.java <==
package io.fabric8.kubernetes.api.model.certificates;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface CertificateSigningRequestSpecFluent<A extends CertificateSigningRequestSpecFluent<A>> extends Fluent<A> {


    public A addToExtra(String key,ArrayList<String> value);
    public A addToExtra(Map<String,ArrayList<String>> map);
    public A removeFromExtra(String key);
    public A removeFromExtra(Map<String,ArrayList<String>> map);
    public Map<String,ArrayList<String>> getExtra();
    public A withExtra(Map<String,ArrayList<String>> extra);
    public Boolean hasExtra();
    public A addToGroups(int index,String item);
    public A setToGroups(int index,String item);
    public A addToGroups(String... items);
    public A addAllToGroups(Collection<String> items);
    public A removeFromGroups(String... items);
    public A removeAllFromGroups(Collection<String> items);
    public List<String> getGroups();
    public String getGroup(int index);
    public String getFirstGroup();
    public String getLastGroup();
    public String getMatchingGroup(Predicate<String> predicate);
    public Boolean hasMatchingGroup(Predicate<String> predicate);
    public A withGroups(List<String> groups);
    public A withGroups(String... groups);
    public Boolean hasGroups();
    public A addNewGroup(String arg1);
    public A addNewGroup(StringBuilder arg1);
    public A addNewGroup(StringBuffer arg1);
    public String getRequest();
    public A withRequest(String request);
    public Boolean hasRequest();
    public A withNewRequest(String arg1);
    public A withNewRequest(StringBuilder arg1);
    public A withNewRequest(StringBuffer arg1);
    public String getSignerName();
    public A withSignerName(String signerName);
    public Boolean hasSignerName();
    public A withNewSignerName(String arg1);
    public A withNewSignerName(StringBuilder arg1);
    public A withNewSignerName(StringBuffer arg1);
    public String getUid();
    public A withUid(String uid);
    public Boolean hasUid();
    public A withNewUid(String arg1);
    public A withNewUid(StringBuilder arg1);
    public A withNewUid(StringBuffer arg1);
    public A addToUsages(int index,String item);
    public A setToUsages(int index,String item);
    public A addToUsages(String... items);
    public A addAllToUsages(Collection<String> items);
    public A removeFromUsages(String... items);
    public A removeAllFromUsages(Collection<String> items);
    public List<String> getUsages();
    public String getUsage(int index);
    public String getFirstUsage();
    public String getLastUsage();
    public String getMatchingUsage(Predicate<String> predicate);
    public Boolean hasMatchingUsage(Predicate<String> predicate);
    public A withUsages(List<String> usages);
    public A withUsages(String... usages);
    public Boolean hasUsages();
    public A addNewUsage(String arg1);
    public A addNewUsage(StringBuilder arg1);
    public A addNewUsage(StringBuffer arg1);
    public String getUsername();
    public A withUsername(String username);
    public Boolean hasUsername();
    public A withNewUsername(String arg1);
    public A withNewUsername(StringBuilder arg1);
    public A withNewUsername(StringBuffer arg1);
}
